| cgd0 | R Documentation |
Data are from a placebo controlled trial of gamma interferon in chronic granulotomous disease (CGD). Contains the data on time to serious infections observed through end of study for each patient.
cgd0
subject identification number
enrolling center
date of randomization
placebo or gamma interferon
sex
age in years, at study entry
height in cm at study entry
weight in kg at study entry
pattern of inheritance
use of steroids at study entry,1=yes
use of prophylactic antibiotics at study entry
a categorization of the centers into 4 groups
days to last follow-up
up to 7 infection times for the subject
This data set is in the form found in the references, with one line per patient and no recoding of the variables.
The usage above assumes that the survival package is attached via
library(survival) or via another package that depends on
survival, e.g., mstate. If not, then either survival::cgd0
or data(cgd, package="survival") can be used.
Fleming and Harrington, Counting Processes and Survival Analysis, appendix D.2.
cgd
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.