This class of objects is returned by the coxph class of functions
to represent a fitted proportional hazards model.
Objects of this class have methods for the functions print,
summary, residuals, predict and survfit.
The following components must be included in a legitimate coxph
object.
coefficientsthe vector of coefficients. If the model is over-determined there will be missing values in the vector corresponding to the redundant columns in the model matrix.
varthe variance matrix of the coefficients. Rows and columns corresponding to any missing coefficients are set to zero.
naive.varthis component will be present only if the robust option was true. If so,
the var component will contain the robust estimate of variance, and this
component will contain the ordinary estimate. (A far better name would
be asymp.var since it contains the model-based asympotitic
variance estimate, which is not necessarily "naive"; but that ship has sailed.)
loglika vector of length 2 containing the log-likelihood with the initial values and with the final values of the coefficients.
scorevalue of the efficient score test, at the initial value of the coefficients.
rscorethe robust log-rank statistic, if a robust variance was requested.
wald.testthe Wald test of whether the final coefficients differ from the initial values.
iternumber of iterations used.
linear.predictorsthe vector of linear predictors, one per subject. Note that this
vector has been centered, see predict.coxph for more details.
residualsthe martingale residuals.
meansvector of values used as the reference for each covariate.
For instance, a later call to predict(fit, type='risk') will
give the hazard ratio between an observation and this reference.
(For most covariates this will contain the mean.)
nthe number of observations used in the fit.
neventthe number of events (usually deaths) used in the fit.
n.idif the call had an id argument, the number of unique
id values
concordancea vector of length 6, containing the number of pairs that are concordant, discordant, tied on x, tied on y, and tied on both, followed by the standard error of the concordance statistic.
firstthe first derivative vector at the solution.
weightsthe vector of case weights, if one was used.
methodthe method used for handling tied survival times.
na.actionthe na.action attribute, if any, that was returned by the na.action
routine.
timefixthe value of the timefix option used in the fit
phZthis is only relevant to multi-state models.
If there were time-dependent covariates that are
completely confounded with a shared proportional baseline, this
component retains those values. They will be treated as the
\(Z\gamma\) term by survfit.coxphms when creating probability
state curves. See the 'Shared coefficients and shared baselines' vignette.
The object will also contain the following, for documentation see the lm
object: terms, assign, formula, call, and, optionally, x, y,
and/or frame.
coxph, coxph.detail, cox.zph, residuals.coxph, survfit, survreg.