| gbsg | R Documentation |
The gbsg data set contains patient records from a 1984-1989 trial
conducted by the German Breast Cancer Study Group (GBSG) of 720 patients
with node positive breast cancer; it retains the 686 patients with
complete data for the prognostic variables.
gbsg
rotterdam
A data set with 686 observations and 11 variables.
pidpatient identifier
ageage, years
menomenopausal status (0= premenopausal, 1= postmenopausal)
sizetumor size, mm
gradetumor grade
nodesnumber of positive lymph nodes
pgrprogesterone receptors (fmol/l)
erestrogen receptors (fmol/l)
hormonhormonal therapy, 0= no, 1= yes
rfstimerecurrence free survival time; days to first of reccurence, death or last follow-up
status0= alive without recurrence, 1= recurrence or death
These data sets are used in the paper by Royston and Altman. The Rotterdam data is used to create a fitted model, and the GBSG data for validation of the model. The paper gives references for the data source.
The usage above assumes that the survival package is attached via
library(survival) or via another package that depends on
survival, e.g., mstate. If not, then either survival::gbsg
or data(cancer, package="survival") can be used.
Patrick Royston and Douglas Altman, External validation of a Cox prognostic model: principles and methods. BMC Medical Research Methodology 2013, 13:33
rotterdam
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.