Learn R Programming

survival (version 2.35-6)

model.matrix.coxph: Model.matrix method for coxph models

Description

Reconstruct the model matrix for a cox model.

Usage

## S3 method for class 'coxph':
model.matrix(object, data, contrast.arg = object$contrasts, ...)

Arguments

object
the result of a coxph model
data
optional, a data frame from which to obtain the data
contrast.arg
optional, a contrasts object describing how factors should be coded
...
other possible argument to model.frame

Value

  • The model matrix for the fit

Details

for details see the documentation of the generic method.

See Also

model.matrix

Examples

Run this code
fit1 <- coxph(Surv(time, status) ~ age + factor(ph.ecog), data=lung)
linear.predictor <- model.matrix(fit1)
fit2 <- coxph(Surv(time, status) ~ age + factor(ph.ecog), data=lung,
                                 x=TRUE)
all.equal(model.matrix(fit1), fit2$x)

Run the code above in your browser using DataLab