| ovarian | R Documentation |
Survival in a randomised trial comparing two treatments for ovarian cancer
ovarian
A data frame with 26 observations and the following variables
futimesurvival or censoring time
fustat0=censored, 1=death
ageage in years
resid.dsresidual disease present (1=no,2=yes)
rxtreatment group, 1= cyclophosphamide, 2= cyclophosphamide + adriamycin
ecog.psECOG performance status (1 is better)
The usage above assumes that the survival package is attached via
library(survival) or via another package that depends on
survival, e.g., mstate. If not, then either survival::ovarian
can be used or data(cancer, package="survival").
Edmunson, J.H., Fleming, T.R., Decker, D.G., Malkasian, G.D., Jefferies, J.A., Webb, M.J., and Kvols, L.K., Different Chemotherapeutic Sensitivities and Host Factors Affecting Prognosis in Advanced Ovarian Carcinoma vs. Minimal Residual Disease. Cancer Treatment Reports, 63:241-47, 1979.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.