Produces a printed summary of a fitted coxph model
# S3 method for summary.coxph
print(x, digits=max(getOption("digits") - 3, 3),
signif.stars = getOption("show.signif.stars"), expand=FALSE, ...)
# S3 method for summary.coxph.penal
print(x, digits=max(getOption("digits") - 3, 3),
signif.stars = getOption("show.signif.stars"), maxlabel=25, ...)
the result of a call to summary.coxph
significant digits to print
Show stars to highlight small p-values
if the summary is for a multi-state coxph fit, print the results in an expanded format
penalized terms can sometimes have very long default labels; this truncates them to better fit on the page
For future methods