Learn R Programming

survival (version 2.41-2)

print.summary.survfit:

Description

Prints the result of summary.survfit.

Usage

# S3 method for summary.survfit
print(x, digits = max(options() $digits-4, 3), ...)

Arguments

x
an object of class "summary.survfit", which is the result of the summary.survfit function.
digits
the number of digits to use in printing the numbers.
…
for future methods

Value

x, with the invisible flag set to prevent printing.

Side Effects

prints the summary created by summary.survfit.

See Also

options, print, summary.survfit.