## S3 method for class 'survfit':
print(x, scale=1,digits = max(options()$digits - 4, 3),print.n=getOption("survfit.print.n"),...)survfit function.scale=365 would scale the printout to years.x, with the invisible flag set.The median and its confidence interval are defined by drawing a horizontal line at 0.5 on the plot of the survival curve and its confidence bands. The intersection of the line with the lower CI band defines the lower limit for the median's interval, and similarly for the upper band. If any of the intersections is not a point, then we use the smallest point of intersection, e.g., if the survival curve were exactly equal to 0.5 over an interval.
The "number of observations" is not well-defined for counting process
data. Previous versions of this code used the number at risk at the
first time point. This is misleading if many individuals enter late or
change strata. The original S code for the current version uses the
number of records, which is misleading with time-dependent
covariates. Four possibilities are provided, controlled by
print.n or by options(survfit.print.n): "none"
prints NA, "records" prints the number of records,
"start" prints the number at the first time point and
"max" prints the maximum number at risk. The initial default is
"start".
summary.survfit##effect of print.n
data(heart)
a<-coxph(Surv(start,stop,event)~age+strata(transplant),data=heart)
b<-survfit(a)
print(b,print.n="none")
print(b,print.n="records")
print(b,print.n="start")
print(b,print.n="max")Run the code above in your browser using DataLab