rats2: Rat data from Gail et al.

rats2R Documentation

Rat data from Gail et al.

Description

48 rats were injected with a carcinogen, and then randomized to either drug or placebo. The number of tumors ranges from 0 to 13; all rats were censored at 6 months after randomization.

Usage

rats2

Format

rat: id
trt: treatment,(1=drug, 0=control)
observation: within rat
start: entry time
stop: exit time
status: event status, 1=tumor, 0=censored

Note

The usage above assumes that the survival package is attached via library(survival) or via another package that depends on survival, e.g., mstate. If not, then either survival::rats2 can be used or data(cancer, package="survival").

MH Gail, TJ Santner, and CC Brown (1980), An analysis of comparative carcinogenesis experiments based on multiple times to tumor. Biometrics 36, 255–266.


survival documentation built on Sept. 10, 2026, 1:07 a.m.