stanford2: More Stanford Heart Transplant data

stanford2R Documentation

More Stanford Heart Transplant data

Description

This contains the Stanford Heart Transplant data in a different format. The main data set is in heart.

Usage

stanford2

Format

id: ID number
time: survival or censoring time
status: censoring status
age: in years
t5: T5 mismatch score

Note

The usage above assumes that the survival package is attached via library(survival) or via another package that depends on survival, e.g., mstate. If not, then either survival::stanford2 can be used or data(heart, package="survival").

LA Escobar and WQ Meeker Jr (1992), Assessing influence in regression analysis with censored data. Biometrics 48, 507–528. Page 519.

See Also

heart


survival documentation built on Sept. 10, 2026, 1:07 a.m.