| coxphms.object | R Documentation |
This class of objects is returned by the coxph class of functions
to represent a fitted hazards model, when the model has
multiple states. The object inherits from the coxph class.
The object has all the components of a coxph object, with the
following additions and variations.
statesa character vector listing the states in the model
cmapthe coefficient map. A matrix containing a column for each transition and a row for each coefficient, the value maps that transition/coefficient pair to a position in the coefficient vector. If a particular covariate is not used by a transition the matrix will contain a zero in that position, if two transitions share a coefficient the matrix will contain repeats.
smapthe stratum map. The row labeled ‘(Baseline)’ identifies transitions that do or do not share a baseline hazard. Further rows correspond to strata() terms in the model, each of which may apply to some transitions and not others.
rmapmapping for the residuals and linear predictors. A two column matrix with one row for each element of the vectors and two columns, the first contains the data row and the second the transition.
In a multi-state model a set of intermediate observations is created
during the computation, with a separate set of data rows for each
transition. An observation (id and time interval) that is at risk for
more than one transition will for instance have a linear predictor and
residual for each of the potential transitions. As a result the vector
of linear predictors will be longer than the number of observations.
The rmap matrix shows the mapping.
coxph, coxph.object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.