If an analysis includes a covariate that was measured repeatedly,
cholesterol say, the data may often include visits where this was not
measured. It is convenient in that case to use, for each subject,
the most recently measured value.
When a value is extended beyond the last measurement, rather that just
replacement of intermediate values, there is the potential for bias,
e.g., if the reason for discontinuation is predictive of the future
trajectory of values.
If time is missing, then the order of the values within subject
is assumed to be the calendar time order. It is not necessary for the
the data to be sorted by id.