survreg.distributionsextreme, gaussian,
logistic and t. The last three
are parametrised in the same way as the distributions already present in
R. The extreme value cdf is
$$F=1-e^{-e^t}.$$When the logarithm of survival time has one of the first three distributions
we obtain respectively lognormal,loglogistic and
weibull.
The other predefined distributions are defined in terms of these. The
exponential and rayleigh distributions are Weibull
distributions with fixed scale of 1 and 0.5 respectively, and
loggaussian is a synonym for lognormal.
survreg,
pnorm,plogis, pt